@@ -10,7 +10,7 @@
 #include <errno.h>
 #include <assert.h>
 
-#include "internal.h"
+#include "internal/internal.h"
 
 /**
  * nfct_conntrack_new - allocate a new conntrack
@@ -443,7 +443,7 @@ int nfct_build_conntrack(struct nfnl_subsys_handle *ssh,
  * 	NFCT_Q_DUMP: dump the conntrack table
  * 	NFCT_Q_DUMP_RESET: dump the conntrack table and reset counters
  *
- * Pass a valid pointer to the protocol family (u_int8_t)
+ * Pass a valid pointer to the protocol family (u_int32_t)
  *
  * On success, 0 is returned. On error, -1 is returned and errno is set
  * appropiately.
@@ -455,7 +455,7 @@ int nfct_build_query(struct nfnl_subsys_handle *ssh,
 		     unsigned int size)
 {
 	struct nfnlhdr *req = buffer;
-	const u_int8_t *family = data;
+	const u_int32_t *family = data;
 
 	assert(ssh != NULL);
 	assert(data != NULL);
@@ -695,12 +695,20 @@ int nfct_compare(const struct nf_conntrack *ct1,
  * @ct2: pointer to a valid conntrack object
  * @flags: flags
  *
- * This function only compare attribute set in both objects, ie. if a certain
- * attribute is not set in ct1 but it is in ct2, then the value of such 
- * attribute is not used in the comparison.
+ * This function only compare attribute set in both objects, by default 
+ * the comparison is not strict, ie. if a certain attribute is not set in one
+ * of the objects, then such attribute is not used in the comparison.
+ * If you want more strict comparisons, you can use the appropriate flags
+ * to modify this behaviour (see NFCT_CMP_STRICT and NFCT_CMP_MASK).
  *
  * The available flags are:
  *
+ * 	- NFCT_CMP_STRICT: the compared objects must have the same attributes
+ * 	and the same values, otherwise it returns that the objects are 
+ * 	different.
+ * 	- NFCT_CMP_MASK: the first object is used as mask, this means that 
+ * 	if an attribute is present in ct1 but not in ct2, this function 
+ * 	returns that the objects are different.
  * 	- NFCT_CMP_ALL: full comparison of both objects
  * 	- NFCT_CMP_ORIG: it only compares the source and destination address;
  * 	source and destination ports; the layer 3 and 4 protocol numbers
@@ -842,3 +850,130 @@ void nfct_copy_attr(struct nf_conntrack *ct1,
 		set_bit(type, ct1->set);
 	}
 }
+
+/**
+ * nfct_filter_create - create a filter
+ *
+ * This function returns a valid pointer on success, otherwise NULL is
+ * returned and errno is appropriately set.
+ */
+struct nfct_filter *nfct_filter_create(void)
+{
+	return calloc(sizeof(struct nfct_filter), 1);
+}
+
+/**
+ * nfct_filter_destroy - destroy a filter
+ * @filter: filter that we want to destroy
+ *
+ * This function releases the memory that is used by the filter object. 
+ * However, please note that this function does *not* detach an already
+ * attached filter.
+ */
+void nfct_filter_destroy(struct nfct_filter *filter)
+{
+	assert(filter != NULL);
+	free(filter);
+	filter = NULL;
+}
+
+/**
+ * nfct_filter_add_attr - add a filter attribute of the filter object
+ * @filter: filter object that we want to modify
+ * @type: filter attribute type
+ * @value: pointer to the value of the filter attribute
+ *
+ * Limitations: You can add up to 256 IPv4 addresses and masks for 
+ * NFCT_FILTER_SRC_IPV4 and, similarly, 256 for NFCT_FILTER_DST_IPV4.
+ */
+void nfct_filter_add_attr(struct nfct_filter *filter,
+			  const enum nfct_filter_attr type, 
+			  const void *value)
+{
+	assert(filter != NULL);
+	assert(value != NULL);
+
+	if (type >= NFCT_FILTER_MAX)
+		return;
+
+	if (filter_attr_array[type]) {
+		filter_attr_array[type](filter, value);
+		set_bit(type, filter->set);
+	}
+}
+
+/**
+ * nfct_filter_add_attr_u32 - add an u32 filter attribute of the filter object
+ * @filter: filter object that we want to modify
+ * @type: filter attribute type
+ * @value: value of the filter attribute using unsigned int (32 bits).
+ */
+void nfct_filter_add_attr_u32(struct nfct_filter *filter,
+			      const enum nfct_filter_attr type,
+			      u_int32_t value)
+{
+	nfct_filter_add_attr(filter, type, &value);
+}
+
+/**
+ * nfct_filter_set_logic - set the filter logic for an attribute type
+ * @filter: filter object that we want to modify
+ * @type: filter attribute type
+ * @logic: filter logic that we want to use
+ *
+ * You can only use this function once to set the filtering logic for 
+ * one attribute. You can define two logics: NFCT_FILTER_POSITIVE_LOGIC
+ * that accept events that match the filter, and NFCT_FILTER_NEGATIVE_LOGIC
+ * that rejects events that match the filter. Default filtering logic is
+ * NFCT_FILTER_POSITIVE_LOGIC.
+ *
+ * On error, it returns -1 and errno is appropriately set. On success, it 
+ * returns 0.
+ */
+int nfct_filter_set_logic(struct nfct_filter *filter,
+			  const enum nfct_filter_attr type,
+			  const enum nfct_filter_logic logic)
+{
+	if (type >= NFCT_FILTER_MAX) {
+		errno = ENOTSUP;
+                return -1;
+	}
+
+	if (filter->logic[type]) {
+		errno = EBUSY;
+		return -1;
+	}
+
+	filter->logic[type] = logic;
+
+	return 0;
+}
+
+/**
+ * nfct_filter_attach - attach a filter to a socket descriptor
+ * @fd: socket descriptor
+ * @filter: filter that we want to attach to the socket
+ *
+ * This function returns -1 on error and set errno appropriately. If the
+ * function returns EINVAL probably you have found a bug in it. Please,
+ * report this.
+ */
+int nfct_filter_attach(int fd, struct nfct_filter *filter)
+{
+	assert(filter != NULL);
+
+	return __setup_netlink_socket_filter(fd, filter);
+}
+
+/**
+ * nfct_filter_detach - detach an existing filter
+ * @fd: socket descriptor
+ *
+ * This function returns -1 on error and set errno appropriately.
+ */
+int nfct_filter_detach(int fd)
+{
+	int val = 0;
+
+	return setsockopt(fd, SOL_SOCKET, SO_DETACH_FILTER, &val, sizeof(val));
+}
